# I/O support
The `nodejs_interop.io` library provides file, socket, HTTP, and other I/O support for [Node.js](https://nodejs.org) applications.

```dart
import 'package:nodejs_interop/io.dart';
```

## Environment
The `nodejs_interop.io` library provides information about the environment in which the current Node.js program is running: the `Platform` class.

```dart
import 'package:nodejs_interop/io.dart';

void main() {
  const platform = const Platform();
  print(platform.operatingSystem); // "linux"
  print(platform.pathSeparator); // "/"
}
```

!!! info
    The implementation is based on the [`platform`](https://pub.dartlang.org/packages/platform) package providing the interfaces.

## File system
The `nodejs_interop.io` library provides a generic representation of the file system: the `FileSystem` class.

```dart
import 'dart:async';
import 'package:nodejs_interop/io.dart';

Future<Null> main() async {
  const fs = const FileSystem();
  print(fs.currentDirectory.path); // "/home/cedric"
  print(fs.isWatchSupported); // true

  var file = fs.file('/etc/motd');
  print(await file.readAsString()); // "Hello World!"
}
```

It also provides a standard set of file-based classes:

- `Directory`
- `ErrorCodes`
- `File`
- `FileLock`
- `FileMode`
- `FileStat`
- `FileSystemEntity`
- `FileSystemEntityType`
- `FileSystemEvent` and its child classes
- `FileSystemException`
- `IOException`
- `OSError`
- `Link`
- `RandomAccessFile`

!!! info
    The implementation is based on the [`file`](https://pub.dartlang.org/packages/file) package providing the interfaces.

## Network / sockets
The `nodejs_interop.io` library provides .... TODO

- `InternetAddress`
- `InternetAddressType`
- `NetworkInterface`
- `SocketException`

## Process management
The `nodejs_interop.io` library provides a manager for the creation of processes: the `ProcessManager` class.

```dart
import 'dart:async';
import 'package:nodejs_interop/io.dart';

Future<Null> main() async {
  const processManager = const ProcessManager();
  var result = await processManager.run(['echo', '-n', 'FooBarBaz']);
  print(result.stdout); // "FooBarBaz"
}
```

TODO Document these features.

- `Process`
- `ProcessException`
- `ProcessInfo`
- `ProcessResult`
- `ProcessSignal`
- `ProcessStartMode`
- `SignalException`

!!! info
    The implementation is based on the [`process`](https://pub.dartlang.org/packages/process) package providing the interfaces.
