part of nodejs_interop.io;
// ignore_for_file: constant_identifier_names

/// [ProcessSignal] is used to send a specific signal to a child process; see [Process.kill].
class ProcessSignal {

  /// Abort signal.
  static const ProcessSignal SIGABRT = const ProcessSignal._internal('SIGABRT');

  /// Timer signal.
  static const ProcessSignal SIGALRM = const ProcessSignal._internal('SIGALRM');

  /// Bus error (bad memory access).
  static const ProcessSignal SIGBUS = const ProcessSignal._internal('SIGBUS');

  /// Child stopped or terminated.
  static const ProcessSignal SIGCHLD = const ProcessSignal._internal('SIGCHLD');

  /// Continue if stopped.
  static const ProcessSignal SIGCONT = const ProcessSignal._internal('SIGCONT');

  /// Floating-point exception.
  static const ProcessSignal SIGFPE = const ProcessSignal._internal('SIGFPE');

  /// Hangup detected on controlling terminal or death of controlling process.
  static const ProcessSignal SIGHUP = const ProcessSignal._internal('SIGHUP');

  /// Illegal instruction.
  static const ProcessSignal SIGILL = const ProcessSignal._internal('SIGILL');

  /// Interrupt from keyboard.
  static const ProcessSignal SIGINT = const ProcessSignal._internal('SIGINT');

  /// Kill signal.
  static const ProcessSignal SIGKILL = const ProcessSignal._internal('SIGKILL');

  /// Broken pipe: write to pipe with no readers.
  static const ProcessSignal SIGPIPE = const ProcessSignal._internal('SIGPIPE');

  /// Pollable event.
  static const ProcessSignal SIGPOLL = const ProcessSignal._internal('SIGPOLL');

  /// Profiling timer expired.
  static const ProcessSignal SIGPROF = const ProcessSignal._internal('SIGPROF');

  /// Quit from keyboard.
  static const ProcessSignal SIGQUIT = const ProcessSignal._internal('SIGQUIT');

  /// Invalid memory reference.
  static const ProcessSignal SIGSEGV = const ProcessSignal._internal('SIGSEGV');

  /// Stop process.
  static const ProcessSignal SIGSTOP = const ProcessSignal._internal('SIGSTOP');

  /// Bad system call.
  static const ProcessSignal SIGSYS = const ProcessSignal._internal('SIGSYS');

  /// Termination signal.
  static const ProcessSignal SIGTERM = const ProcessSignal._internal('SIGTERM');

  /// Trace/breakpoint trap.
  static const ProcessSignal SIGTRAP = const ProcessSignal._internal('SIGTRAP');

  /// Stop typed at terminal.
  static const ProcessSignal SIGTSTP = const ProcessSignal._internal('SIGTSTP');

  /// Terminal input for background process.
  static const ProcessSignal SIGTTIN = const ProcessSignal._internal('SIGTTIN');

  /// Terminal output for background process.
  static const ProcessSignal SIGTTOU = const ProcessSignal._internal('SIGTTOU');

  /// Urgent condition on socket.
  static const ProcessSignal SIGURG = const ProcessSignal._internal('SIGURG');

  /// User-defined signal 1.
  static const ProcessSignal SIGUSR1 = const ProcessSignal._internal('SIGUSR1');

  /// User-defined signal 2.
  static const ProcessSignal SIGUSR2 = const ProcessSignal._internal('SIGUSR2');

  /// Virtual alarm clock.
  static const ProcessSignal SIGVTALRM = const ProcessSignal._internal('SIGVTALRM');

  /// Window resize signal.
  static const ProcessSignal SIGWINCH = const ProcessSignal._internal('SIGWINCH');

  /// CPU time limit exceeded.
  static const ProcessSignal SIGXCPU = const ProcessSignal._internal('SIGXCPU');

  /// File size limit exceeded.
  static const ProcessSignal SIGXFSZ = const ProcessSignal._internal('SIGXFSZ');

  /// The signal's name.
  final String _name;

  /// Creates a new process signal.
  const ProcessSignal._internal(this._name);

  /// Returns a string representation of this object.
  @override
  String toString() => _name;

  /// Watch for process signals.
  /// A signal can be watched multiple times, from multiple isolates, where all callbacks are invoked when signaled, in no specific order.
  Stream<ProcessSignal> watch() {
    var controller = new StreamController<ProcessSignal>();
    controller.onCancel = controller.close;
    process.on(_name, allowInterop((signal) => controller.add(this)));
    return controller.stream;
  }
}
