part of nodejs_interop.node;

/// A function invoked when an operation is finally completed.
typedef void CompletionCallback0([JSError error]);

/// A function invoked with a value when an operation is finally completed.
typedef void CompletionCallback1<T>(JSError error, [T value]);

/// A function invoked with two values when an operation is finally completed.
typedef void CompletionCallback2<T1, T2>(JSError error, [T1 value1, T2 value2]);

/// Converts the specified [readable] stream to a [Stream].
Stream<T> asStream<T>(Readable<T> readable) {
  var controller = new StreamController<T>();
  readable
    ..on('data', allowInterop((data) => controller.add(data)))
    ..on('end', allowInterop(controller.close))
    ..on('error', allowInterop((error) => controller.addError(error)));

  return controller.stream;
}

/// Requires the JavaScript module with the specified [identifier].
///
/// Throws a [DeferredLoadException] if the module could not be required.
/// If a [onError] handler is provided, it is called with the [identifier] as argument, and its return value is used instead.
///
/// This function is prefered to the [require] function because it properly exposes to the Dart engine the classes exported by the required module.
T loadLibrary<T>(String identifier, {T onError(String identifier)}) {
  try {
    T module = require(identifier);
    var moduleId = '\$${identifier.replaceAll(new RegExp('[-/@.]'), '_')}';
    if (!hasProperty(global, moduleId)) setProperty(global, moduleId, module);
    return module;
  }

  on JSError {
    if (onError != null) return onError(identifier);
    throw new DeferredLoadException(identifier);
  }
}
