import 'dart:async';
import 'dart:js';
import 'package:nodejs_interop/node.dart';
import 'package:test/test.dart';

/// Tests the features of the [DnsModule] class.
void main() => group('DnsModule', () {
  final DnsModule dns = require('dns');
  final NetModule net = require('net');

  group('.lookup()', () {
    test('should resolve the hostname into the first found IP address', () async {
      var completer = new Completer<List>();
      dns.lookup('belin.io', allowInterop((error, [address, family]) {
        if (error == null) completer.complete([address, family]);
        else completer.completeError(error);
      }));

      var result = await completer.future;
      expect(net.isIPv4(result.first), isTrue);
      expect(result.last, equals(4));
    });

    test('should resolve the hostname into an IPv6 address', () async {
      var completer = new Completer<List>();
      dns.lookup('google.com', 6, allowInterop((error, [address, family]) {
        if (error == null) completer.complete([address, family]);
        else completer.completeError(error);
      }));

      var result = await completer.future;
      expect(net.isIPv6(result.first), isTrue);
      expect(result.last, equals(6));
    });

    test('should resolve the hostname into a list of IP addresses', () async {
      var completer = new Completer<List>();
      dns.lookup('belin.io', new LookupOptions(all: true), allowInterop((error, [addresses]) {
        if (error == null) completer.complete(addresses);
        else completer.completeError(error);
      }));

      var addresses = await completer.future;
      expect(addresses, hasLength(1));
      expect(net.isIPv4(addresses.first.address), isTrue);
      expect(addresses.first.family, equals(4));
    });
  });

  group('.lookupService()', () {
    test('should resolve the given address and port into a `hostname` and `service`', () async {
      var completer = new Completer<List<String>>();
      dns.lookupService('163.172.221.182', 80, allowInterop((error, [hostname, service]) {
        if (error == null) completer.complete([hostname, service]);
        else completer.completeError(error);
      }));

      var result = await completer.future;
      expect(result.first, anyOf(equals('ns.belin.io'), equals('sd-100506'), equals('sd-100506.dedibox.fr')));
      expect(result.last, equals('http'));
    });
  });
});
